@@ -2,15 +2,25 @@ package Catalyst::Plugin::Unicode;
 
 use strict;
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 sub finalize {
     my $c = shift;
 
-    if ( $c->response->body && $c->response->content_type =~ /^text/ ) {
-        utf8::encode( $c->response->{body} );
+    unless ( $c->response->body ) {
+        return $c->NEXT::finalize;
     }
 
+    unless ( $c->response->content_type =~ /^text/ ) {
+        return $c->NEXT::finalize;
+    }
+
+    unless ( utf8::is_utf8( $c->response->body ) ) {
+        return $c->NEXT::finalize;
+    }
+
+    utf8::encode( $c->response->{body} );
+
     $c->NEXT::finalize;
 }
 
@@ -47,18 +57,18 @@ Catalyst::Plugin::Unicode - Unicode aware Catalyst
 On request, decodes all params from UTF-8 octets into a sequence of 
 logical characters. On response, encodes body into UTF-8 octets.
 
-=head1 OVERRIDDEN METHODS
+=head1 OVERLOADED METHODS
 
 =over 4
 
 =item finalize
 
-Encodes body as UTF-8 octets.
+Encodes body into UTF-8 octets.
 
 =item prepare_parameters
 
-Encode parameters as UTF-8 octets.
- 
+Decodes parameters into a sequence of logical characters.
+
 =back
 
 =head1 SEE ALSO
